@@ -6,7 +6,7 @@ import struct
 from abc import abstractmethod
 from collections import deque
 from contextlib import suppress
-from typing import Any, Optional
+from typing import Any, BinaryIO, Deque, Dict, Literal, Optional, cast
 
 
 class _BaseQueueMeta(type):
@@ -14,10 +14,12 @@ class _BaseQueueMeta(type):
     Metaclass to check queue classes against the necessary interface
     """
 
-    def __instancecheck__(cls, instance):
-        return cls.__subclasscheck__(type(instance))  # pylint: disable=no-value-for-parameter
+    def __instancecheck__(cls, instance: Any) -> bool:
+        return cls.__subclasscheck__(  # pylint: disable=no-value-for-parameter
+            type(instance)
+        )
 
-    def __subclasscheck__(cls, subclass):
+    def __subclasscheck__(cls, subclass: Any) -> bool:
         return (
             hasattr(subclass, "push")
             and callable(subclass.push)
@@ -46,7 +48,7 @@ class BaseQueue(metaclass=_BaseQueueMeta):
         raise NotImplementedError()
 
     @abstractmethod
-    def __len__(self):
+    def __len__(self) -> int:
         raise NotImplementedError()
 
     def close(self) -> None:
@@ -57,7 +59,7 @@ class FifoMemoryQueue:
     """In-memory FIFO queue, API compliant with FifoDiskQueue."""
 
     def __init__(self) -> None:
-        self.q = deque()  # type: deque
+        self.q: Deque[Any] = deque()
 
     def push(self, obj: Any) -> None:
         self.q.append(obj)
@@ -71,7 +73,7 @@ class FifoMemoryQueue:
     def close(self) -> None:
         pass
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self.q)
 
 
@@ -103,7 +105,7 @@ class FifoDiskQueue:
 
     def push(self, string: bytes) -> None:
         if not isinstance(string, bytes):
-            raise TypeError("Unsupported type: {}".format(type(string).__name__))
+            raise TypeError(f"Unsupported type: {type(string).__name__}")
         hnum, hpos = self.info["head"]
         hpos += 1
         szhdr = struct.pack(self.szhdr_format, len(string))
@@ -116,8 +118,8 @@ class FifoDiskQueue:
         self.info["size"] += 1
         self.info["head"] = [hnum, hpos]
 
-    def _openchunk(self, number: int, mode: str = "rb"):
-        return open(os.path.join(self.path, "q%05d" % number), mode)
+    def _openchunk(self, number: int, mode: Literal["rb", "ab+"] = "rb") -> BinaryIO:
+        return open(os.path.join(self.path, f"q{number:05d}"), mode)
 
     def pop(self) -> Optional[bytes]:
         tnum, tcnt, toffset = self.info["tail"]
@@ -163,13 +165,13 @@ class FifoDiskQueue:
             self._cleanup()
 
     def __len__(self) -> int:
-        return self.info["size"]
+        return cast(int, self.info["size"])
 
-    def _loadinfo(self, chunksize: int) -> dict:
+    def _loadinfo(self, chunksize: int) -> Dict[str, Any]:
         infopath = self._infopath()
         if os.path.exists(infopath):
             with open(infopath) as f:
-                info = json.load(f)
+                info = cast(Dict[str, Any], json.load(f))
         else:
             info = {
                 "chunksize": chunksize,
@@ -179,7 +181,7 @@ class FifoDiskQueue:
             }
         return info
 
-    def _saveinfo(self, info: dict) -> None:
+    def _saveinfo(self, info: Dict[str, Any]) -> None:
         with open(self._infopath(), "w") as f:
             json.dump(info, f)
 
@@ -201,6 +203,7 @@ class LifoDiskQueue:
     SIZE_SIZE = struct.calcsize(SIZE_FORMAT)
 
     def __init__(self, path: str) -> None:
+        self.size: int
         self.path = path
         if os.path.exists(path):
             self.f = open(path, "rb+")
@@ -214,7 +217,7 @@ class LifoDiskQueue:
 
     def push(self, string: bytes) -> None:
         if not isinstance(string, bytes):
-            raise TypeError("Unsupported type: {}".format(type(string).__name__))
+            raise TypeError(f"Unsupported type: {type(string).__name__}")
         self.f.write(string)
         ssize = struct.pack(self.SIZE_FORMAT, len(string))
         self.f.write(ssize)
@@ -269,7 +272,7 @@ class FifoSQLiteQueue:
 
     def push(self, item: bytes) -> None:
         if not isinstance(item, bytes):
-            raise TypeError("Unsupported type: {}".format(type(item).__name__))
+            raise TypeError(f"Unsupported type: {type(item).__name__}")
         with self._db as conn:
             conn.execute(self._sql_push, (item,))
 
@@ -277,13 +280,13 @@ class FifoSQLiteQueue:
         with self._db as conn:
             for id_, item in conn.execute(self._sql_pop):
                 conn.execute(self._sql_del, (id_,))
-                return item
+                return cast(bytes, item)
         return None
 
     def peek(self) -> Optional[bytes]:
         with self._db as conn:
             for _, item in conn.execute(self._sql_pop):
-                return item
+                return cast(bytes, item)
         return None
 
     def close(self) -> None:
@@ -294,7 +297,7 @@ class FifoSQLiteQueue:
 
     def __len__(self) -> int:
         with self._db as conn:
-            return next(conn.execute(self._sql_size))[0]
+            return cast(int, next(conn.execute(self._sql_size))[0])
 
 
 class LifoSQLiteQueue(FifoSQLiteQueue):
